package com.ibm.eis.mdrr.query.server;

import java.util.Set;

/**
 * Functions required of the application-specific class to evaluate a <cmdbf:relationshipTemplate>.
 * These functions are invoked indirectly by the XSLT transform through the template evaluator,
 * which may be the DefaultTemplateEvaluator or one supplied by the framework user.
 */
public interface IRelationshipTemplateEvaluator {

	/**
	 * @return name of the relationship template, from the id attribute of the <cmdbf:relationshipTemplate> element 
	 */
	public String getTemplateName();

	/**
	 * @return name of the source item template, from the ref attribute of the <cmdbf:sourceTemplate> element 
	 */
	public String getSourceTemplateName();

	/**
	 * @return name of the target item template, from the ref attribute of the <cmdbf:targetTemplate> element 
	 */
	public String getTargetTemplateName();
	
	/**
	 * @return a set of IRelationships specified by this relationship template
	 * @throws CMDBfException
	 */
	public Set<IRelationship> evaluate(Set<IItem> source, Set<IItem> target);
}
