package com.ibm.eis.mdrr.query.server;

import java.util.List;

import org.w3c.dom.traversal.NodeIterator;

/**
 * Functions used by the XSLT transformation to create and evaluate item/relationship templates
 * specified in a CMDBf query.
 */
public interface ITemplateEvaluator {

	/**
	 * 
	 */
	public static final String TEMPLATE_EVALUATOR_PROPERTY = "templateEvaluator";
	
	/**
	 * @param itemTemplateIterator a NodeIterator for one <cmdbf:itemTemplate> element
	 * @return an IItemTemplateEvaluator for the node specified by the NodeIterator
	 * @throws CMDBfException
	 */
	public IItemTemplateEvaluator createItemTemplateEvaluator(NodeIterator itemTemplateIterator) throws CMDBfException ;
	
	/**
	 * @param templateName an item template name, specified by the id attribute of a <cmdbf:itemTemplate>
	 * @return a List of IItems that constitute the results of this item template's query
	 * @throws CMDBfException
	 */
	public List<IItem> getItemTemplateResults(String templateName) throws CMDBfException ;
	
	/**
	 * @param relationshipTemplateIterator a NodeIterator for one <cmdbf:relationshipTemplate> element
	 * @return an IRelationshipTemplateEvaluator for the node specified by the NodeIterator
	 * @throws CMDBfException
	 */
	public IRelationshipTemplateEvaluator createRelationshipTemplateEvaluator(NodeIterator relationshipTemplateIterator) throws CMDBfException;
	
	/**
	 * @param templateName a relationship template name, specified by the id attribute of a <cmdbf:relationshipTemplate>
	 * @return a List of IRelationship that constitute the results of this relationship template's query
	 * @throws CMDBfException
	 */
	public List<IRelationship> getRelationshipTemplateResults(String templateName) throws CMDBfException;
}
